@@ -1,7 +1,7 @@
 """
 Contains some fields as utilities.
 """
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _
 from django.db import models
 from django.utils.text import capfirst
 from upy import forms
